# Copyright (C) 2009-2011 Canonical Ltd 

import os.path
import sys


from launchpadlib.credentials import Credentials

from launchpadlib.launchpad import (
    Launchpad, 
    )

from launchpadlib.uris import (
    LPNET_SERVICE_ROOT,
    )


service_root = os.environ.get(
    'LAUNCHPAD_API', 
    LPNET_SERVICE_ROOT)


def trace(s):
    sys.stderr.write(s + '\n')


def create_session():
    # Due to <http://pad.lv/752095> and changes in lplib, we now rely on it to
    # set the cache, credential store, etc.
    #
    # NB: Generally naming the parameters seems safer, but in this case the
    # first changed from 'consumer_name' to 'application_name' in natty.
    #
    # Specify WRITE_PRIVATE access so the user doesn't get a confusing list of
    # options then a strange HTTP error later if they picked read-only. See:
    #
    # <http://pad.lv/643610>
    # <http://jameswestby.net/weblog/tech/16-Improving-the-usability-of-launchpadlib-using-code.html>
    #
    # Unfortunately launchpadlib doesn't detect if existing credentials have
    # insufficient access so we can't ask for lesser permissions then upgrade
    # as required later. As hydrazine runs under direct control of the user,
    # always having the ability to change everything isn't too bad.
    return Launchpad.login_with(
        'hydrazine',
        allow_access_levels=['WRITE_PRIVATE'],
        service_root=LPNET_SERVICE_ROOT)
